@@ -1,5 +1,5 @@
 ## Copyright (C) 2013,2014 Markus Bergholz
-## Parts Copyright (C) 2014-2015 Philip Nienhuis
+## Parts Copyright (C) 2014-2016 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -19,32 +19,12 @@
 ## tested with MS Excel 2010, Gnumeric, LibreOffice 4.x
 ##
 ## usage:
-##	__OCT_oct2xlsx__(filename, matrix, wsh, range, spsh_opts)
-##
-##	matrix: have to be a 2D cell array. NaN will be an empty cell in Excel.
-##
-##	wsh: can be a 1, 2 or 3 for indexing the worksheet. >3 is not supported yet!
-##	wsh: can be string for naming the worksheet. the string has a limit length of 31!
-##	wsh can be a cell for defining worksheet index and name at the same time. e.g. {2,'Made by Octave'}
-##	xlswrite('default.xlsx',m) % default written to Table 1, named "Table1"
-##	xlswrite('filename.xlsx',m,3) % written to Table 3, named "Table3"
-##	xlswrite('another.xlsx',k,'string named') % written to Table 1, named "string named"
-##	xlswrite('impressive.xlsx',data,{'my data',2}) % written to Table 2, named "my data"
-##	xlswrite('impressive.xlsx',datay,{3, 'my other data'}) % written to Table 3, named "my other data"
-##	xlswrite('next.xlsx',data,{'my data',2},'B2') % values will start at B2 (temporary broken!)
-##
-##	octave:85> m=rand(100,100);
-##	octave:86> tic, xlsxwrite('test20.xlsx',m); toc
-##	Elapsed time is 3.1919641494751 seconds.
-##
-##	octave:97> m=rand(1234,702);
-##	octave:98> tic, xlsxwrite('interesting.xlsx',m); toc
-##	Elapsed time is 253.35110616684 seconds.
+## __OCT_oct2xlsx__(filename, matrix, wsh, range, spsh_opts)
 ## @end deftypefn
 
 ## Author: Markus Bergholz <markuman at gmail.com>
 ## Amended by Philip Nienhuis <prnienhuis at users.sf.net>
-## 2013/11/08		- Initial Release
+## 2013/11/08 - Initial Release
 
 function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_opts, obj_dims)
 
@@ -81,7 +61,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
       new_sh = 1;
       ## Default sheet name
       wsh_string = sprintf ("Sheet%d", wsh);
-      ## It may already exist...
+      ## Name may already be in use... append underscores
       while (! isempty (find (strcmp (wsh_string, xls.sheets.sh_names))) && ...
              length (wsh_string <= 31))
         wsh_string = strrep (wsh_string, "Sheet", "Sheet_");
@@ -117,7 +97,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
   ##   * For each string check if it is in <temp>/sharedStrings.xml
   ##     > if YES, put pointer in new worksheet
   ##     > if NO, add node in sharedStrings.xml and pointer in new worksheet
-  ## - If needed (new file) update <temp>/workbook.xml w. sheet name & sheetId
+  ## - If needed (new file) update <temp>/workbook.xml w. sheet name & a sheetId
   ##   higher than any existing sheetId
   ## - Update workbook.xml.rels
 
@@ -363,8 +343,6 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
   typearr = spsh_prstype (arrdat, onr, onc, [1:5], spsh_opts);
 
   if (all (typearr(:) == 1))        ## Numeric
-#   write arrdat to sheet%%WSH%%.xml
-#  __OOXML_turbowrite__(sprintf("%s/xl/worksheets/sheet%d.xml",tmpdir,wsh_number), arrdat);
     for r=1:rows (arrdat)
       fprintf (fid, '<row r="%d" spans="%d:%d" x14ac:dyDescent="0.25">', ...
                r+lims(2, 1)-1, ...
@@ -391,15 +369,18 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
           ## File exists => there are already some strings in the sheet
           shstr = fread (sid, "char=>char").';
           fclose (sid);
-          ## Extract string values. May be much more than present in current sheet
-          strings = cell2mat (regexp (shstr, '<si><t(?:.*?>(.*?)</t>|(.+?)/>)</si>', "tokens"));
+          ## Extract string values. May be much more than present in current sheet.
+          ## A two-step procedure is required to preserve empty strings ("<t/>")
+          strings = cell2mat (regexp (shstr, '<si[^>]*>(.*?)</si>', "tokens"));
+          strings = regexprep (strings, '(^<t>|^<t/>|</t>$)', "");
           ## Watch out for a rare corner case: just one empty string... (avoid [])
           if (isempty (strings))
             strings = {""};
           endif
-          uniq_str_cnt = str2double (getxmlattv (shstr, "uniqueCount"));
-          ##uniq_str_cnt = numel (unique (strings));
-          ## Make shstr a mueric value
+          sst = getxmlnode (shstr, "sst", 1);
+          uniq_str_cnt = str2double (getxmlattv (sst, "uniqueCount"));
+          clear sst;
+          ## Make shstr a numeric value
           shstr = 1;
         else
           ## File didn't exist yet
