@@ -1,4 +1,4 @@
-## Copyright (C) 2013-2015 Philip Nienhuis
+## Copyright (C) 2013-2016 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -23,26 +23,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2013-09-08
-## Updates:
-## 2013-09-09 Fix getxmlnode call
-##     ''     boolean, percentage & currency tags properly handled
-## 2013-09-11 Properly skip empty upper table-rows
-##     ''     Return dates as strings to avoid misinterpreting plethora of formats
-##     ''     Try-catch construct for time values
-##     ''     Formula reading support
-## 2013-09-23 Renamed to __OCT_ods2oct__.m
-## 2013-09-29 Use values between <text> tags only for strings & dates/times
-##     ''     Return date values as Octave datenums (doubles)
-##     ''     Return requested range rather than entire sheet data
-## 2013-10-01 Little adaptation in header
-## 2013-10-01 Read sheets from disk rather than keep them in memory
-## 2013-11-03 Fix bug with updating column ptr after repeated columns node
-## 2013-11-13 Fix table-row counter bug
-##     ''     Pretty text output
-## 2013-12-19 Work around OTK bug (doesn't write office:value-type for formula cells)
-## 2014-01-22 Copyright string update
-## 2014-01-23 Pretty formula output
-## 2015-03-07 Replace deprecated strmatch
 
 function [ rawarr, ods, rstatus] = __OCT_ods2oct__ (ods, wsh, cellrange='', spsh_opts)
 
@@ -307,5 +287,6 @@ function [ rawarr, ods, rstatus] = __OCT_ods2oct__ (ods, wsh, cellrange='', spsh
   endif
   ## Keep track of data rectangle limits
   ods.limits = [lcol, rcol; firstrow, lastrow];
+  rstatus = 1;
 
 endfunction
