@@ -1,4 +1,4 @@
-## Copyright (C) 2012 Philip Nienhuis <prnienhuis@users.sf.net>
+## Copyright (C) 2012-2016 Philip Nienhuis <prnienhuis@users.sf.net>
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,9 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
 
 function [ xls ] = __OXS_spsh_close__ (xls)
 
@@ -32,19 +29,13 @@ function [ xls ] = __OXS_spsh_close__ (xls)
       endif
       try
         xlsout = javaObject ("java.io.FileOutputStream", fname);
-        bufout = javaObject ("java.io.BufferedOutputStream", xlsout);
-        if (xls.changed == 2) printf ("Saving file %s...\n", fname); endif
-        xls.workbook.writeBytes (bufout);
-        xls.workbook.close ();
-        bufout.flush ();
-        bufout.close ();
+        xls.workbook.write (xlsout);
         xlsout.close ();
         xls.changed = 0;
       catch
-##      xlsout.close ();
+        warning ("__OXS_spsh_close__: error trying to close OXS file ptr");
       end_try_catch
-    else
-      xls.workbook.close ();
     endif
+    xls.workbook.close ();
 
 endfunction
