@@ -1,4 +1,4 @@
-## Copyright (C) 2011-2015 Philip Nienhuis
+## Copyright (C) 2011-2016 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -17,20 +17,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2011-05-18
-## 2011-09-18 Adapted sh_names type to LO 3.4.1
-## 2011-09-23 Removed stray debug statements
-## 2012-02-25 Fixed wrong var name in L.933
-## 2012-02-25 Catch stray Java RuntimeException when deleting sheets
-## 2012-02-26 Bug fix when adding sheets near L.994 (wrong if-else-end construct).
-## 2012-02-27 Copyright strings updated
-## 2012-05-21 "Double" cast added when writing numeric values
-## 2012-05-21 "Double" cast moved into main func oct2xls
-## 2012-10-12 Renamed & moved into ./private
-## 2012-10-24 Style fixes
-## 2012-12-21 Search for exact match when searching sheet names
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-06 Updated copyright string
-## 2015-03-07 Replace deprecated strmatch
 
 function [ xls, rstatus ] = __UNO_oct2spsh__ (c_arr, xls, wsh, crange, spsh_opts)
 
