@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2015 Philip Nienhuis
+## Copyright (C) 2009-2016 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,7 @@
 ## @deftypefn {Function File} [@var{filetype}] = xlsfinfo (@var{filename} [, @var{reqintf}])
 ## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}] = xlsfinfo (@var{filename} [, @var{reqintf}])
 ## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}, @var{fformat}] = xlsfinfo (@var{filename} [, @var{reqintf}])
+## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}, @var{fformat}, @var{nmranges}] = xlsfinfo (@var{filename} [, @var{reqintf}])
 ## Query Excel spreadsheet file @var{filename} for some info about its
 ## contents.
 ##
@@ -33,25 +34,33 @@
 ## Optional return value @var{fformat} currently returns @'' (empty
 ## string) unless @var{filename} is a readable Excel 97-2003 .xls file or
 ## an Excel 2007 .xlsx / .xlsb file in which case @var{fformat} is set to
-## "xlWorkbookNormal". Excel 95 .xls files can only be read through the JXL
+## "xlWorkbookNormal".  Excel 95 .xls files can only be read through the JXL
 ## (JExcelAPI) or UNO (OpenOffice.org) Java-based interfaces.
 ##
+## Optional return argument @var{nmranges} is a cell array containing all
+## named data ranges in the file in the first column, the relevant sheet and
+## the cell range in the second and third column and if appropriate the
+## scope of the range in the fourth column. For named ranges defined for
+## the entire workbook the fourth column entry is empty.
+## Named ranges only work for the COM, POI, OXS, UNO and OCT interfaces.
+##
 ## If no return arguments are specified the sheet names are echoed to the 
 ## terminal screen; in case of Java interfaces for each sheet the actual
-## occupied data range is echoed as well. The occupied cell range will have
+## occupied data range is echoed as well.  The occupied cell range will have
 ## to be determined behind the scenes first; this can take some time for the
-## Java-based interfaces.
+## Java-based interfaces.  Any Named ranges defined in the spreadsheet file
+## will be listed on screen as well.
 ##
 ## If multiple xls interfaces have been installed, @var{reqintf} can be
-## specified. This can sometimes be handy, e.g. to get an idea of occupied
+## specified.  This can sometimes be handy, e.g. to get an idea of occupied
 ## cell ranges in each worksheet using different interfaces (due to cached
 ## info and/or different treatment of empty but formatted cells, each
 ## interfaces may give different results).
 ##
 ## For OOXML spreadsheets no external SW is required but full POI and/or
 ## UNO support (see xlsopen) may work better or faster; to use those specify
-## 'poi' or 'uno' for @var{reqintf}. For Excel 95 files use 'com' (windows
-## only), 'jxl' or 'uno'. Gnumeric files can be explored with the built-in
+## 'poi' or 'uno' for @var{reqintf}.  For Excel 95 files use 'com' (windows
+## only), 'jxl' or 'uno'.  Gnumeric files can be explored with the built-in
 ## OCT interface (no need to specify @var{reqintf} then).
 ##
 ## Examples:
@@ -73,32 +82,8 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sourceforge.net>
 ## Created: 2009-10-27
-## Updates:
-## 2009-01-01 Echo sheet names to screen, request interface type)
-## 2010-03-21 Better tabulated output; occupied date range per sheet echoed 
-##            for Java interfaces (though it may be a bit off in case of JXL)
-## 2010-05-31 Added remark about delays when determining occupied data range
-## 2010-08-25 Improved help text (Excel file types)
-## 2010-10-06 Added ";" to str2 declaration
-##     ''     Added occupied range echo for COM interface (may be a bit off too)
-## 2010-10-10 Made output arg2 contain only address ranges (or other sheet type names)
-## 2010-11-01 Added other file type strings for return arg #3 (fformat)
-## 2011-03-26 Added OpenXLS support
-## 2011-05-18 Experimental UNO support
-## 2011-09-08 Some code simplifications
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-25 Added info on occupied ranges to sh_names outarg for all interfaces
-## 2012-10-12 Moved all interface-specific code into ./private subfuncs
-## 2012-10-24 Style fixes
-## 2013-10-01 OCT interface added for gnumeric
-## 2013-12-01 Style fixes & support for more file types than just Excel
-## 2013-12-29 Style fixes
-## 2014-04-15 Updates to texinfo header
-## 2014-04-26 Fix error messages (no more traceback)
-## 2014-05-01 Also check for leading period in file extension
-## 2015-03-06 Replace deprecated strmatch()
 
-function [ filetype, sh_names, fformat ] = xlsfinfo (filename, reqintf=[])
+function [ filetype, sh_names, fformat, nmranges ] = xlsfinfo (filename, reqintf=[])
 
   persistent str2; str2 = "                                 "; ## 33 spaces
   persistent lstr2; lstr2 = length (str2);
@@ -161,8 +146,23 @@ function [ filetype, sh_names, fformat ] = xlsfinfo (filename, reqintf=[])
       endif
       printf ("%s%s%s\n", str1, str2(1:lstr2-length (sh_names{ii, 1})), str3);
     endfor
+    ## Echo named ranges
+    nmranges = getnmranges (xls);
+    snmr = size (nmranges, 1);
+    if(snmr > 0)
+      ## Find max length of entries
+      nmrl = min (35, max ([cellfun("length", nmranges(:, 1)); 10]));
+      shtl = min (31, max ([cellfun("length", nmranges(:, 2)); 6]));
+      rnml = max ([cellfun("length", nmranges(:, 3)); 5]);
+      frmt = sprintf ("%%%ds  %%%ds  %%%ds\n" , nmrl, shtl, rnml);
+      printf (["\n" frmt], "Range name", "Sheet", "Range");
+      printf (frmt, "----------", "-----", "-----" );
+      for ii=1:size (nmranges, 1)
+        printf (frmt, nmranges(ii, 1:3){:});
+      endfor
+    endif
   else
-    if (sh_cnt > 0)
+    if (sh_cnt > 0 && nargout > 2)
       if (strcmpi (xls.filename(end-2:end), "xls"))
         fformat = "xlWorkbookNormal";
       elseif (strcmpi (xls.filename(end-2:end), "csv"))
@@ -175,6 +175,10 @@ function [ filetype, sh_names, fformat ] = xlsfinfo (filename, reqintf=[])
         fformat = "";
       endif
     endif
+    if (nargout > 3)
+      ## Echo named ranges
+      nmranges = getnmranges (xls);
+    endif
   endif
 
   xlsclose (xls);
